Module: Google::Apis::ConnectorsV2

Defined in:
lib/google/apis/connectors_v2.rb,
lib/google/apis/connectors_v2/classes.rb,
lib/google/apis/connectors_v2/service.rb,
lib/google/apis/connectors_v2/gem_version.rb,
lib/google/apis/connectors_v2/representations.rb

Overview

Connectors API

Enables users to create and manage connections to Google Cloud services and third-party business applications using the Connectors interface.

Defined Under Namespace

Classes: AccessCredentials, Action, AuthCodeData, CheckReadinessResponse, CheckStatusResponse, ConnectorsService, DailyCycle, Date, DenyMaintenancePeriod, Empty, Entity, EntityType, ExchangeAuthCodeRequest, ExchangeAuthCodeResponse, ExecuteActionRequest, ExecuteActionResponse, ExecuteSqlQueryRequest, ExecuteSqlQueryResponse, ExecuteToolRequest, ExecuteToolResponse, ExecutionConfig, Field, GenerateCustomToolspecRequest, GenerateCustomToolspecResponse, GetResourcePostRequest, GetResourceResponse, InputParameter, Instance, JsonSchema, ListActionsResponse, ListCustomToolNamesResponse, ListEntitiesResponse, ListEntityTypesResponse, ListResourcesResponse, ListToolsPostRequest, ListToolsResponse, MaintenancePolicy, MaintenanceSchedule, MaintenanceSettings, MaintenanceWindow, NodeSloMetadata, NotificationParameter, OAuth2Config, PerSliSloEligibility, ProvisionedResource, Query, QueryParameter, Reference, RefreshAccessTokenRequest, RefreshAccessTokenResponse, Resource, ResultMetadata, Schedule, SloEligibility, SloMetadata, TimeOfDay, Tool, ToolAnnotations, ToolName, ToolSpec, UpdateEntitiesWithConditionsResponse, UpdatePolicy, WeeklyCycle

Constant Summary collapse

GEM_VERSION =

Version of the google-apis-connectors_v2 gem

"0.33.0"
GENERATOR_VERSION =

Version of the code generator used to generate this client

"0.18.0"
REVISION =

Revision of the discovery document this client was generated from

"20260427"
VERSION =

Version of the Connectors API this client connects to. This is NOT the gem version.

'V2'
AUTH_CLOUD_PLATFORM =

See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.

'https://www.googleapis.com/auth/cloud-platform'