Class: Google::Apis::ConnectorsV2::AuthCodeData

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v2/classes.rb,
lib/google/apis/connectors_v2/representations.rb,
lib/google/apis/connectors_v2/representations.rb

Overview

AuthCodeData contains the data the runtime plane will give the connector backend in exchange for access and refresh tokens.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AuthCodeData

Returns a new instance of AuthCodeData.



145
146
147
# File 'lib/google/apis/connectors_v2/classes.rb', line 145

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auth_codeString

OAuth authorization code. Corresponds to the JSON property authCode

Returns:

  • (String)


127
128
129
# File 'lib/google/apis/connectors_v2/classes.rb', line 127

def auth_code
  @auth_code
end

#pkce_verifierString

OAuth PKCE verifier, needed if PKCE is enabled for this particular connection. Corresponds to the JSON property pkceVerifier

Returns:

  • (String)


132
133
134
# File 'lib/google/apis/connectors_v2/classes.rb', line 132

def pkce_verifier
  @pkce_verifier
end

#redirect_uriString

OAuth redirect URI passed in during the auth code flow, required by some OAuth backends. Corresponds to the JSON property redirectUri

Returns:

  • (String)


138
139
140
# File 'lib/google/apis/connectors_v2/classes.rb', line 138

def redirect_uri
  @redirect_uri
end

#scopesArray<String>

Scopes the connection will request when the user performs the auth code flow. Corresponds to the JSON property scopes

Returns:

  • (Array<String>)


143
144
145
# File 'lib/google/apis/connectors_v2/classes.rb', line 143

def scopes
  @scopes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



150
151
152
153
154
155
# File 'lib/google/apis/connectors_v2/classes.rb', line 150

def update!(**args)
  @auth_code = args[:auth_code] if args.key?(:auth_code)
  @pkce_verifier = args[:pkce_verifier] if args.key?(:pkce_verifier)
  @redirect_uri = args[:redirect_uri] if args.key?(:redirect_uri)
  @scopes = args[:scopes] if args.key?(:scopes)
end