Class: Google::Apis::ConnectorsV2::ConnectorsService
- Inherits:
-
Google::Apis::Core::BaseService
- Object
- Google::Apis::Core::BaseService
- Google::Apis::ConnectorsV2::ConnectorsService
- Defined in:
- lib/google/apis/connectors_v2/service.rb
Overview
Connectors API
Enables users to create and manage connections to Google Cloud services and third-party business applications using the Connectors interface.
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://connectors.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#check_project_location_connection_readiness(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::CheckReadinessResponse
Reports readiness status of the connector.
-
#check_project_location_connection_status(name, execution_config_headers: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::CheckStatusResponse
Reports the status of the connection.
-
#create_project_location_connection_entity_type_entity(parent, entity_object = nil, execution_config_headers: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::Entity
Creates a new entity row of the specified entity type in the external system.
-
#delete_project_location_connection_entity_type_entity(name, execution_config_headers: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::Empty
Deletes an existing entity row matching the entity type and entity id specified in the request.
-
#delete_project_location_connection_entity_type_entity_entities_with_conditions(entity_type, conditions: nil, execution_config_headers: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::Empty
Deletes entities based on conditions specified in the request and not on entity id.
-
#exchange_connection_auth_code(name, exchange_auth_code_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::ExchangeAuthCodeResponse
ExchangeAuthCode exchanges the OAuth authorization code (and other necessary data) for an access token (and associated credentials).
-
#execute_action(name, execute_action_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::ExecuteActionResponse
Executes an action with the name specified in the request.
-
#execute_connection_sql_query(connection, execute_sql_query_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::ExecuteSqlQueryResponse
Executes a SQL statement specified in the body of the request.
-
#execute_tool(name, execute_tool_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::ExecuteToolResponse
Executes a specific tool.
-
#generate_project_location_connection_connection_toolspec_override(name, generate_custom_toolspec_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::GenerateCustomToolspecResponse
Generate toolspec override for the given list of toolNames.
-
#get_project_location_connection_action(name, execution_config_headers: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::Action
Gets the schema of the given action.
-
#get_project_location_connection_entity_type(name, context_metadata: nil, execution_config_headers: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::EntityType
Gets metadata of given entity type.
-
#get_project_location_connection_entity_type_entity(name, execution_config_headers: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::Entity
Gets a single entity row matching the entity type and entity id specified in the request.
-
#get_project_location_connection_resource(name, execution_config_headers: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::GetResourceResponse
Gets a specific resource.
-
#get_resource_post(name, get_resource_post_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::GetResourceResponse
Gets a specific resource with POST.
-
#initialize ⇒ ConnectorsService
constructor
A new instance of ConnectorsService.
-
#list_project_location_connection_actions(parent, execution_config_headers: nil, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::ListActionsResponse
Gets the schema of all the actions supported by the connector.
-
#list_project_location_connection_custom_tool_names(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::ListCustomToolNamesResponse
Lists custom tool names.
-
#list_project_location_connection_entity_type_entities(parent, conditions: nil, execution_config_headers: nil, page_size: nil, page_token: nil, sort_by: nil, sort_order: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::ListEntitiesResponse
Lists entity rows of a particular entity type contained in the request.
-
#list_project_location_connection_entity_types(parent, execution_config_headers: nil, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::ListEntityTypesResponse
Lists metadata related to all entity types present in the external system.
-
#list_project_location_connection_resources(parent, execution_config_headers: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::ListResourcesResponse
Lists all available resources.
-
#list_project_location_connection_tools(parent, execution_config_headers: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::ListToolsResponse
Lists all available tools.
-
#patch_project_location_connection_entity_type_entity(name, entity_object = nil, execution_config_headers: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::Entity
Updates an existing entity row matching the entity type and entity id specified in the request.
-
#refresh_connection_access_token(name, refresh_access_token_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::RefreshAccessTokenResponse
RefreshAccessToken exchanges the OAuth refresh token (and other necessary data) for a new access token (and new associated credentials).
-
#tools_project_location_connection(parent, list_tools_post_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::ListToolsResponse
Lists all available tools with POST.
-
#update_project_location_connection_entity_type_entity_entities_with_conditions(entity_type, entity_object = nil, conditions: nil, execution_config_headers: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::UpdateEntitiesWithConditionsResponse
Updates entities based on conditions specified in the request and not on entity id.
Constructor Details
#initialize ⇒ ConnectorsService
Returns a new instance of ConnectorsService.
48 49 50 51 52 53 |
# File 'lib/google/apis/connectors_v2/service.rb', line 48 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-connectors_v2', client_version: Google::Apis::ConnectorsV2::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
41 42 43 |
# File 'lib/google/apis/connectors_v2/service.rb', line 41 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
46 47 48 |
# File 'lib/google/apis/connectors_v2/service.rb', line 46 def quota_user @quota_user end |
Instance Method Details
#check_project_location_connection_readiness(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::CheckReadinessResponse
Reports readiness status of the connector. Similar logic to GetStatus but modified for kubernetes health check to understand.
75 76 77 78 79 80 81 82 83 |
# File 'lib/google/apis/connectors_v2/service.rb', line 75 def check_project_location_connection_readiness(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}:checkReadiness', ) command.response_representation = Google::Apis::ConnectorsV2::CheckReadinessResponse::Representation command.response_class = Google::Apis::ConnectorsV2::CheckReadinessResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#check_project_location_connection_status(name, execution_config_headers: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::CheckStatusResponse
Reports the status of the connection. Note that when the connection is in a state that is not ACTIVE, the implementation of this RPC method must return a Status with the corresponding State instead of returning a gRPC status code that is not "OK", which indicates that ConnectionStatus itself, not the connection, failed.
112 113 114 115 116 117 118 119 120 121 |
# File 'lib/google/apis/connectors_v2/service.rb', line 112 def check_project_location_connection_status(name, execution_config_headers: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}:checkStatus', ) command.response_representation = Google::Apis::ConnectorsV2::CheckStatusResponse::Representation command.response_class = Google::Apis::ConnectorsV2::CheckStatusResponse command.params['name'] = name unless name.nil? command.query['executionConfig.headers'] = execution_config_headers unless execution_config_headers.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_connection_entity_type_entity(parent, entity_object = nil, execution_config_headers: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::Entity
Creates a new entity row of the specified entity type in the external system.
The field values for creating the row are contained in the body of the request.
The response message contains a Entity message object returned as a
response by the external system.
565 566 567 568 569 570 571 572 573 574 575 576 |
# File 'lib/google/apis/connectors_v2/service.rb', line 565 def create_project_location_connection_entity_type_entity(parent, entity_object = nil, execution_config_headers: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+parent}/entities', ) command.request_representation = Google::Apis::ConnectorsV2::Entity::Representation command.request_object = entity_object command.response_representation = Google::Apis::ConnectorsV2::Entity::Representation command.response_class = Google::Apis::ConnectorsV2::Entity command.params['parent'] = parent unless parent.nil? command.query['executionConfig.headers'] = execution_config_headers unless execution_config_headers.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_connection_entity_type_entity(name, execution_config_headers: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::Empty
Deletes an existing entity row matching the entity type and entity id specified in the request.
604 605 606 607 608 609 610 611 612 613 |
# File 'lib/google/apis/connectors_v2/service.rb', line 604 def delete_project_location_connection_entity_type_entity(name, execution_config_headers: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v2/{+name}', ) command.response_representation = Google::Apis::ConnectorsV2::Empty::Representation command.response_class = Google::Apis::ConnectorsV2::Empty command.params['name'] = name unless name.nil? command.query['executionConfig.headers'] = execution_config_headers unless execution_config_headers.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_connection_entity_type_entity_entities_with_conditions(entity_type, conditions: nil, execution_config_headers: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::Empty
Deletes entities based on conditions specified in the request and not on entity id.
649 650 651 652 653 654 655 656 657 658 659 |
# File 'lib/google/apis/connectors_v2/service.rb', line 649 def delete_project_location_connection_entity_type_entity_entities_with_conditions(entity_type, conditions: nil, execution_config_headers: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+entityType}/entities:deleteEntitiesWithConditions', ) command.response_representation = Google::Apis::ConnectorsV2::Empty::Representation command.response_class = Google::Apis::ConnectorsV2::Empty command.params['entityType'] = entity_type unless entity_type.nil? command.query['conditions'] = conditions unless conditions.nil? command.query['executionConfig.headers'] = execution_config_headers unless execution_config_headers.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#exchange_connection_auth_code(name, exchange_auth_code_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::ExchangeAuthCodeResponse
ExchangeAuthCode exchanges the OAuth authorization code (and other necessary data) for an access token (and associated credentials).
144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/google/apis/connectors_v2/service.rb', line 144 def exchange_connection_auth_code(name, exchange_auth_code_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+name}:exchangeAuthCode', ) command.request_representation = Google::Apis::ConnectorsV2::ExchangeAuthCodeRequest::Representation command.request_object = exchange_auth_code_request_object command.response_representation = Google::Apis::ConnectorsV2::ExchangeAuthCodeResponse::Representation command.response_class = Google::Apis::ConnectorsV2::ExchangeAuthCodeResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#execute_action(name, execute_action_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::ExecuteActionResponse
Executes an action with the name specified in the request. The input parameters for executing the action are passed through the body of the ExecuteAction request.
348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/google/apis/connectors_v2/service.rb', line 348 def execute_action(name, execute_action_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+name}:execute', ) command.request_representation = Google::Apis::ConnectorsV2::ExecuteActionRequest::Representation command.request_object = execute_action_request_object command.response_representation = Google::Apis::ConnectorsV2::ExecuteActionResponse::Representation command.response_class = Google::Apis::ConnectorsV2::ExecuteActionResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#execute_connection_sql_query(connection, execute_sql_query_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::ExecuteSqlQueryResponse
Executes a SQL statement specified in the body of the request. An example of this SQL statement in the case of Salesforce connector would be 'select * from Account a, Order o where a.Id = o.AccountId'.
180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/google/apis/connectors_v2/service.rb', line 180 def execute_connection_sql_query(connection, execute_sql_query_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+connection}:executeSqlQuery', ) command.request_representation = Google::Apis::ConnectorsV2::ExecuteSqlQueryRequest::Representation command.request_object = execute_sql_query_request_object command.response_representation = Google::Apis::ConnectorsV2::ExecuteSqlQueryResponse::Representation command.response_class = Google::Apis::ConnectorsV2::ExecuteSqlQueryResponse command.params['connection'] = connection unless connection.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#execute_tool(name, execute_tool_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::ExecuteToolResponse
Executes a specific tool.
986 987 988 989 990 991 992 993 994 995 996 |
# File 'lib/google/apis/connectors_v2/service.rb', line 986 def execute_tool(name, execute_tool_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+name}:execute', ) command.request_representation = Google::Apis::ConnectorsV2::ExecuteToolRequest::Representation command.request_object = execute_tool_request_object command.response_representation = Google::Apis::ConnectorsV2::ExecuteToolResponse::Representation command.response_class = Google::Apis::ConnectorsV2::ExecuteToolResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#generate_project_location_connection_connection_toolspec_override(name, generate_custom_toolspec_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::GenerateCustomToolspecResponse
Generate toolspec override for the given list of toolNames.
214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/google/apis/connectors_v2/service.rb', line 214 def generate_project_location_connection_connection_toolspec_override(name, generate_custom_toolspec_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+name}:generateConnectionToolspecOverride', ) command.request_representation = Google::Apis::ConnectorsV2::GenerateCustomToolspecRequest::Representation command.request_object = generate_custom_toolspec_request_object command.response_representation = Google::Apis::ConnectorsV2::GenerateCustomToolspecResponse::Representation command.response_class = Google::Apis::ConnectorsV2::GenerateCustomToolspecResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_connection_action(name, execution_config_headers: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::Action
Gets the schema of the given action.
387 388 389 390 391 392 393 394 395 396 397 |
# File 'lib/google/apis/connectors_v2/service.rb', line 387 def get_project_location_connection_action(name, execution_config_headers: nil, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}', ) command.response_representation = Google::Apis::ConnectorsV2::Action::Representation command.response_class = Google::Apis::ConnectorsV2::Action command.params['name'] = name unless name.nil? command.query['executionConfig.headers'] = execution_config_headers unless execution_config_headers.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_connection_entity_type(name, context_metadata: nil, execution_config_headers: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::EntityType
Gets metadata of given entity type
476 477 478 479 480 481 482 483 484 485 486 487 |
# File 'lib/google/apis/connectors_v2/service.rb', line 476 def get_project_location_connection_entity_type(name, context_metadata: nil, execution_config_headers: nil, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}', ) command.response_representation = Google::Apis::ConnectorsV2::EntityType::Representation command.response_class = Google::Apis::ConnectorsV2::EntityType command.params['name'] = name unless name.nil? command.query['contextMetadata'] = unless .nil? command.query['executionConfig.headers'] = execution_config_headers unless execution_config_headers.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_connection_entity_type_entity(name, execution_config_headers: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::Entity
Gets a single entity row matching the entity type and entity id specified in the request.
687 688 689 690 691 692 693 694 695 696 |
# File 'lib/google/apis/connectors_v2/service.rb', line 687 def get_project_location_connection_entity_type_entity(name, execution_config_headers: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}', ) command.response_representation = Google::Apis::ConnectorsV2::Entity::Representation command.response_class = Google::Apis::ConnectorsV2::Entity command.params['name'] = name unless name.nil? command.query['executionConfig.headers'] = execution_config_headers unless execution_config_headers.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_connection_resource(name, execution_config_headers: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::GetResourceResponse
Gets a specific resource.
877 878 879 880 881 882 883 884 885 886 |
# File 'lib/google/apis/connectors_v2/service.rb', line 877 def get_project_location_connection_resource(name, execution_config_headers: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}', ) command.response_representation = Google::Apis::ConnectorsV2::GetResourceResponse::Representation command.response_class = Google::Apis::ConnectorsV2::GetResourceResponse command.params['name'] = name unless name.nil? command.query['executionConfig.headers'] = execution_config_headers unless execution_config_headers.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_resource_post(name, get_resource_post_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::GetResourceResponse
Gets a specific resource with POST.
910 911 912 913 914 915 916 917 918 919 920 |
# File 'lib/google/apis/connectors_v2/service.rb', line 910 def get_resource_post(name, get_resource_post_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+name}', ) command.request_representation = Google::Apis::ConnectorsV2::GetResourcePostRequest::Representation command.request_object = get_resource_post_request_object command.response_representation = Google::Apis::ConnectorsV2::GetResourceResponse::Representation command.response_class = Google::Apis::ConnectorsV2::GetResourceResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_connection_actions(parent, execution_config_headers: nil, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::ListActionsResponse
Gets the schema of all the actions supported by the connector.
432 433 434 435 436 437 438 439 440 441 442 443 444 |
# File 'lib/google/apis/connectors_v2/service.rb', line 432 def list_project_location_connection_actions(parent, execution_config_headers: nil, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+parent}/actions', ) command.response_representation = Google::Apis::ConnectorsV2::ListActionsResponse::Representation command.response_class = Google::Apis::ConnectorsV2::ListActionsResponse command.params['parent'] = parent unless parent.nil? command.query['executionConfig.headers'] = execution_config_headers unless execution_config_headers.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_connection_custom_tool_names(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::ListCustomToolNamesResponse
Lists custom tool names.
247 248 249 250 251 252 253 254 255 |
# File 'lib/google/apis/connectors_v2/service.rb', line 247 def list_project_location_connection_custom_tool_names(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+name}:listCustomToolNames', ) command.response_representation = Google::Apis::ConnectorsV2::ListCustomToolNamesResponse::Representation command.response_class = Google::Apis::ConnectorsV2::ListCustomToolNamesResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_connection_entity_type_entities(parent, conditions: nil, execution_config_headers: nil, page_size: nil, page_token: nil, sort_by: nil, sort_order: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::ListEntitiesResponse
Lists entity rows of a particular entity type contained in the request. Note:
- Currently, only max of one 'sort_by' column is supported. 2. If no 'sort_by' column is provided, the primary key of the table is used. If zero or more than one primary key is available, we default to the unpaginated list entities logic which only returns the first page. 3. The values of the 'sort_by' columns must uniquely identify an entity row, otherwise undefined behaviors may be observed during pagination. 4. Since transactions are not supported, any updates, inserts or deletes during pagination can lead to stale data being returned or other unexpected behaviors.
744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 |
# File 'lib/google/apis/connectors_v2/service.rb', line 744 def list_project_location_connection_entity_type_entities(parent, conditions: nil, execution_config_headers: nil, page_size: nil, page_token: nil, sort_by: nil, sort_order: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+parent}/entities', ) command.response_representation = Google::Apis::ConnectorsV2::ListEntitiesResponse::Representation command.response_class = Google::Apis::ConnectorsV2::ListEntitiesResponse command.params['parent'] = parent unless parent.nil? command.query['conditions'] = conditions unless conditions.nil? command.query['executionConfig.headers'] = execution_config_headers unless execution_config_headers.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['sortBy'] = sort_by unless sort_by.nil? command.query['sortOrder'] = sort_order unless sort_order.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_connection_entity_types(parent, execution_config_headers: nil, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::ListEntityTypesResponse
Lists metadata related to all entity types present in the external system.
522 523 524 525 526 527 528 529 530 531 532 533 534 |
# File 'lib/google/apis/connectors_v2/service.rb', line 522 def list_project_location_connection_entity_types(parent, execution_config_headers: nil, page_size: nil, page_token: nil, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+parent}/entityTypes', ) command.response_representation = Google::Apis::ConnectorsV2::ListEntityTypesResponse::Representation command.response_class = Google::Apis::ConnectorsV2::ListEntityTypesResponse command.params['parent'] = parent unless parent.nil? command.query['executionConfig.headers'] = execution_config_headers unless execution_config_headers.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_connection_resources(parent, execution_config_headers: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::ListResourcesResponse
Lists all available resources.
951 952 953 954 955 956 957 958 959 960 961 962 |
# File 'lib/google/apis/connectors_v2/service.rb', line 951 def list_project_location_connection_resources(parent, execution_config_headers: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+parent}/resources', ) command.response_representation = Google::Apis::ConnectorsV2::ListResourcesResponse::Representation command.response_class = Google::Apis::ConnectorsV2::ListResourcesResponse command.params['parent'] = parent unless parent.nil? command.query['executionConfig.headers'] = execution_config_headers unless execution_config_headers.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_connection_tools(parent, execution_config_headers: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::ListToolsResponse
Lists all available tools.
1027 1028 1029 1030 1031 1032 1033 1034 1035 1036 1037 1038 |
# File 'lib/google/apis/connectors_v2/service.rb', line 1027 def list_project_location_connection_tools(parent, execution_config_headers: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v2/{+parent}/tools', ) command.response_representation = Google::Apis::ConnectorsV2::ListToolsResponse::Representation command.response_class = Google::Apis::ConnectorsV2::ListToolsResponse command.params['parent'] = parent unless parent.nil? command.query['executionConfig.headers'] = execution_config_headers unless execution_config_headers.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_connection_entity_type_entity(name, entity_object = nil, execution_config_headers: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::Entity
Updates an existing entity row matching the entity type and entity id
specified in the request. The fields in the entity row that need to be
modified are contained in the body of the request. All unspecified fields are
left unchanged. The response message contains a Entity message object
returned as a response by the external system.
790 791 792 793 794 795 796 797 798 799 800 801 |
# File 'lib/google/apis/connectors_v2/service.rb', line 790 def patch_project_location_connection_entity_type_entity(name, entity_object = nil, execution_config_headers: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v2/{+name}', ) command.request_representation = Google::Apis::ConnectorsV2::Entity::Representation command.request_object = entity_object command.response_representation = Google::Apis::ConnectorsV2::Entity::Representation command.response_class = Google::Apis::ConnectorsV2::Entity command.params['name'] = name unless name.nil? command.query['executionConfig.headers'] = execution_config_headers unless execution_config_headers.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#refresh_connection_access_token(name, refresh_access_token_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::RefreshAccessTokenResponse
RefreshAccessToken exchanges the OAuth refresh token (and other necessary data) for a new access token (and new associated credentials).
278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/google/apis/connectors_v2/service.rb', line 278 def refresh_connection_access_token(name, refresh_access_token_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+name}:refreshAccessToken', ) command.request_representation = Google::Apis::ConnectorsV2::RefreshAccessTokenRequest::Representation command.request_object = refresh_access_token_request_object command.response_representation = Google::Apis::ConnectorsV2::RefreshAccessTokenResponse::Representation command.response_class = Google::Apis::ConnectorsV2::RefreshAccessTokenResponse command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#tools_project_location_connection(parent, list_tools_post_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::ListToolsResponse
Lists all available tools with POST.
312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/google/apis/connectors_v2/service.rb', line 312 def tools_project_location_connection(parent, list_tools_post_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+parent}/tools', ) command.request_representation = Google::Apis::ConnectorsV2::ListToolsPostRequest::Representation command.request_object = list_tools_post_request_object command.response_representation = Google::Apis::ConnectorsV2::ListToolsResponse::Representation command.response_class = Google::Apis::ConnectorsV2::ListToolsResponse command.params['parent'] = parent unless parent.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#update_project_location_connection_entity_type_entity_entities_with_conditions(entity_type, entity_object = nil, conditions: nil, execution_config_headers: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ConnectorsV2::UpdateEntitiesWithConditionsResponse
Updates entities based on conditions specified in the request and not on entity id.
838 839 840 841 842 843 844 845 846 847 848 849 850 |
# File 'lib/google/apis/connectors_v2/service.rb', line 838 def update_project_location_connection_entity_type_entity_entities_with_conditions(entity_type, entity_object = nil, conditions: nil, execution_config_headers: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v2/{+entityType}/entities:updateEntitiesWithConditions', ) command.request_representation = Google::Apis::ConnectorsV2::Entity::Representation command.request_object = entity_object command.response_representation = Google::Apis::ConnectorsV2::UpdateEntitiesWithConditionsResponse::Representation command.response_class = Google::Apis::ConnectorsV2::UpdateEntitiesWithConditionsResponse command.params['entityType'] = entity_type unless entity_type.nil? command.query['conditions'] = conditions unless conditions.nil? command.query['executionConfig.headers'] = execution_config_headers unless execution_config_headers.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |