Class: Google::Apis::ConnectorsV2::DenyMaintenancePeriod
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV2::DenyMaintenancePeriod
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v2/classes.rb,
lib/google/apis/connectors_v2/representations.rb,
lib/google/apis/connectors_v2/representations.rb
Overview
DenyMaintenancePeriod definition. Maintenance is forbidden within the deny period. The start_date must be less than the end_date.
Instance Attribute Summary collapse
-
#end_date ⇒ Google::Apis::ConnectorsV2::Date
Represents a whole or partial calendar date, such as a birthday.
-
#start_date ⇒ Google::Apis::ConnectorsV2::Date
Represents a whole or partial calendar date, such as a birthday.
-
#time ⇒ Google::Apis::ConnectorsV2::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DenyMaintenancePeriod
constructor
A new instance of DenyMaintenancePeriod.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DenyMaintenancePeriod
Returns a new instance of DenyMaintenancePeriod.
313 314 315 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 313 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_date ⇒ Google::Apis::ConnectorsV2::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property endDate
292 293 294 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 292 def end_date @end_date end |
#start_date ⇒ Google::Apis::ConnectorsV2::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property startDate
304 305 306 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 304 def start_date @start_date end |
#time ⇒ Google::Apis::ConnectorsV2::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property time
311 312 313 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 311 def time @time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
318 319 320 321 322 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 318 def update!(**args) @end_date = args[:end_date] if args.key?(:end_date) @start_date = args[:start_date] if args.key?(:start_date) @time = args[:time] if args.key?(:time) end |