Class: Google::Apis::ConnectorsV2::Entity

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v2/classes.rb,
lib/google/apis/connectors_v2/representations.rb,
lib/google/apis/connectors_v2/representations.rb

Overview

'Entity row'/ 'Entity' refers to a single row of an entity type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Entity

Returns a new instance of Entity.



362
363
364
# File 'lib/google/apis/connectors_v2/classes.rb', line 362

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fieldsHash<String,Object>

Fields of the entity. The key is name of the field and the value contains the applicable google.protobuf.Value entry for this field. Corresponds to the JSON property fields

Returns:

  • (Hash<String,Object>)


349
350
351
# File 'lib/google/apis/connectors_v2/classes.rb', line 349

def fields
  @fields
end

#metadataHash<String,Hash<String,Object>>

Metadata like service latency, etc. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Hash<String,Object>>)


354
355
356
# File 'lib/google/apis/connectors_v2/classes.rb', line 354

def 
  @metadata
end

#nameString

Output only. Resource name of the Entity. Format: projects/project/locations/ location/connections/connection/entityTypes/type/entities/id Corresponds to the JSON property name

Returns:

  • (String)


360
361
362
# File 'lib/google/apis/connectors_v2/classes.rb', line 360

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



367
368
369
370
371
# File 'lib/google/apis/connectors_v2/classes.rb', line 367

def update!(**args)
  @fields = args[:fields] if args.key?(:fields)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
end