Class: Google::Apis::ConnectorsV2::ExchangeAuthCodeResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v2/classes.rb,
lib/google/apis/connectors_v2/representations.rb,
lib/google/apis/connectors_v2/representations.rb

Overview

ExchangeAuthCodeResponse includes the returned access token and its associated credentials.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExchangeAuthCodeResponse

Returns a new instance of ExchangeAuthCodeResponse.



472
473
474
# File 'lib/google/apis/connectors_v2/classes.rb', line 472

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_credentialsGoogle::Apis::ConnectorsV2::AccessCredentials

AccessCredentials includes the OAuth access token, and the other fields returned along with it. Corresponds to the JSON property accessCredentials



465
466
467
# File 'lib/google/apis/connectors_v2/classes.rb', line 465

def access_credentials
  @access_credentials
end

#metadataHash<String,Hash<String,Object>>

Metadata like service latency, etc. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,Hash<String,Object>>)


470
471
472
# File 'lib/google/apis/connectors_v2/classes.rb', line 470

def 
  @metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



477
478
479
480
# File 'lib/google/apis/connectors_v2/classes.rb', line 477

def update!(**args)
  @access_credentials = args[:access_credentials] if args.key?(:access_credentials)
  @metadata = args[:metadata] if args.key?(:metadata)
end