Class: Google::Apis::ConnectorsV2::ExecuteSqlQueryResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v2/classes.rb,
lib/google/apis/connectors_v2/representations.rb,
lib/google/apis/connectors_v2/representations.rb

Overview

A response returned by the connection after executing the sql query.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExecuteSqlQueryResponse

Returns a new instance of ExecuteSqlQueryResponse.



573
574
575
# File 'lib/google/apis/connectors_v2/classes.rb', line 573

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resultsArray<Hash<String,Object>>

In the case of successful execution of the query the response contains results returned by the external system. For example, the result rows of the query are contained in the 'results' Struct list - "results": [ "field1": "val1", " field2": "val2",..,.. ] Each Struct row can contain fields any type of like nested Structs or lists. Corresponds to the JSON property results

Returns:

  • (Array<Hash<String,Object>>)


571
572
573
# File 'lib/google/apis/connectors_v2/classes.rb', line 571

def results
  @results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



578
579
580
# File 'lib/google/apis/connectors_v2/classes.rb', line 578

def update!(**args)
  @results = args[:results] if args.key?(:results)
end