Class: Google::Apis::ConnectorsV2::Field
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV2::Field
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v2/classes.rb,
lib/google/apis/connectors_v2/representations.rb,
lib/google/apis/connectors_v2/representations.rb
Overview
Message contains EntityType's Field metadata.
Instance Attribute Summary collapse
-
#additional_details ⇒ Hash<String,Object>
The following map contains fields that are not explicitly mentioned above,this give connectors the flexibility to add new metadata fields.
-
#data_type ⇒ String
The data type of the Field.
-
#default_value ⇒ Object
The following field specifies the default value of the Field provided by the external system if a value is not provided.
-
#description ⇒ String
A brief description of the Field.
-
#json_schema ⇒ Google::Apis::ConnectorsV2::JsonSchema
JsonSchema representation of schema metadata Corresponds to the JSON property
jsonSchema. -
#key ⇒ Boolean
(also: #key?)
The following boolean field specifies if the current Field acts as a primary key or id if the parent is of type entity.
-
#name ⇒ String
Name of the Field.
-
#nullable ⇒ Boolean
(also: #nullable?)
Specifies whether a null value is allowed.
-
#reference ⇒ Google::Apis::ConnectorsV2::Reference
Reference captures the association between two different entity types.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Field
constructor
A new instance of Field.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Field
Returns a new instance of Field.
721 722 723 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 721 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_details ⇒ Hash<String,Object>
The following map contains fields that are not explicitly mentioned above,this
give connectors the flexibility to add new metadata fields.
Corresponds to the JSON property additionalDetails
674 675 676 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 674 def additional_details @additional_details end |
#data_type ⇒ String
The data type of the Field.
Corresponds to the JSON property dataType
679 680 681 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 679 def data_type @data_type end |
#default_value ⇒ Object
The following field specifies the default value of the Field provided by the
external system if a value is not provided.
Corresponds to the JSON property defaultValue
685 686 687 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 685 def default_value @default_value end |
#description ⇒ String
A brief description of the Field.
Corresponds to the JSON property description
690 691 692 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 690 def description @description end |
#json_schema ⇒ Google::Apis::ConnectorsV2::JsonSchema
JsonSchema representation of schema metadata
Corresponds to the JSON property jsonSchema
695 696 697 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 695 def json_schema @json_schema end |
#key ⇒ Boolean Also known as: key?
The following boolean field specifies if the current Field acts as a primary
key or id if the parent is of type entity.
Corresponds to the JSON property key
701 702 703 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 701 def key @key end |
#name ⇒ String
Name of the Field.
Corresponds to the JSON property name
707 708 709 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 707 def name @name end |
#nullable ⇒ Boolean Also known as: nullable?
Specifies whether a null value is allowed.
Corresponds to the JSON property nullable
712 713 714 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 712 def nullable @nullable end |
#reference ⇒ Google::Apis::ConnectorsV2::Reference
Reference captures the association between two different entity types. Value
links to the reference of another entity type.
Corresponds to the JSON property reference
719 720 721 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 719 def reference @reference end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
726 727 728 729 730 731 732 733 734 735 736 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 726 def update!(**args) @additional_details = args[:additional_details] if args.key?(:additional_details) @data_type = args[:data_type] if args.key?(:data_type) @default_value = args[:default_value] if args.key?(:default_value) @description = args[:description] if args.key?(:description) @json_schema = args[:json_schema] if args.key?(:json_schema) @key = args[:key] if args.key?(:key) @name = args[:name] if args.key?(:name) @nullable = args[:nullable] if args.key?(:nullable) @reference = args[:reference] if args.key?(:reference) end |