Class: Google::Apis::ConnectorsV2::InputParameter

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v2/classes.rb,
lib/google/apis/connectors_v2/representations.rb,
lib/google/apis/connectors_v2/representations.rb

Overview

Input Parameter message contains metadata about the parameters required for executing an Action.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InputParameter

Returns a new instance of InputParameter.



884
885
886
# File 'lib/google/apis/connectors_v2/classes.rb', line 884

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_detailsHash<String,Object>

The following map contains fields that are not explicitly mentioned above,this give connectors the flexibility to add new metadata fields. Corresponds to the JSON property additionalDetails

Returns:

  • (Hash<String,Object>)


850
851
852
# File 'lib/google/apis/connectors_v2/classes.rb', line 850

def additional_details
  @additional_details
end

#data_typeString

The data type of the Parameter Corresponds to the JSON property dataType

Returns:

  • (String)


855
856
857
# File 'lib/google/apis/connectors_v2/classes.rb', line 855

def data_type
  @data_type
end

#default_valueObject

The following field specifies the default value of the Parameter provided by the external system if a value is not provided. Corresponds to the JSON property defaultValue

Returns:

  • (Object)


861
862
863
# File 'lib/google/apis/connectors_v2/classes.rb', line 861

def default_value
  @default_value
end

#descriptionString

A brief description of the Parameter. Corresponds to the JSON property description

Returns:

  • (String)


866
867
868
# File 'lib/google/apis/connectors_v2/classes.rb', line 866

def description
  @description
end

#json_schemaGoogle::Apis::ConnectorsV2::JsonSchema

JsonSchema representation of schema metadata Corresponds to the JSON property jsonSchema



871
872
873
# File 'lib/google/apis/connectors_v2/classes.rb', line 871

def json_schema
  @json_schema
end

#nameString

Name of the Parameter. Corresponds to the JSON property name

Returns:

  • (String)


876
877
878
# File 'lib/google/apis/connectors_v2/classes.rb', line 876

def name
  @name
end

#nullableBoolean Also known as: nullable?

Specifies whether a null value is allowed. Corresponds to the JSON property nullable

Returns:

  • (Boolean)


881
882
883
# File 'lib/google/apis/connectors_v2/classes.rb', line 881

def nullable
  @nullable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



889
890
891
892
893
894
895
896
897
# File 'lib/google/apis/connectors_v2/classes.rb', line 889

def update!(**args)
  @additional_details = args[:additional_details] if args.key?(:additional_details)
  @data_type = args[:data_type] if args.key?(:data_type)
  @default_value = args[:default_value] if args.key?(:default_value)
  @description = args[:description] if args.key?(:description)
  @json_schema = args[:json_schema] if args.key?(:json_schema)
  @name = args[:name] if args.key?(:name)
  @nullable = args[:nullable] if args.key?(:nullable)
end