Class: Google::Apis::ConnectorsV2::ListToolsPostRequest
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV2::ListToolsPostRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v2/classes.rb,
lib/google/apis/connectors_v2/representations.rb,
lib/google/apis/connectors_v2/representations.rb
Overview
Request message for ConnectorAgentService.ListToolsPost
Instance Attribute Summary collapse
-
#execution_config ⇒ Google::Apis::ConnectorsV2::ExecutionConfig
execution config for the request.
-
#page_size ⇒ Fixnum
Page size.
-
#page_token ⇒ String
Page token.
-
#tool_names ⇒ Array<String>
List of tool names to for selective tool fetching.
-
#tool_spec ⇒ Google::Apis::ConnectorsV2::ToolSpec
List of tool specifications.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListToolsPostRequest
constructor
A new instance of ListToolsPostRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListToolsPostRequest
Returns a new instance of ListToolsPostRequest.
1577 1578 1579 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 1577 def initialize(**args) update!(**args) end |
Instance Attribute Details
#execution_config ⇒ Google::Apis::ConnectorsV2::ExecutionConfig
execution config for the request.
Corresponds to the JSON property executionConfig
1555 1556 1557 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 1555 def execution_config @execution_config end |
#page_size ⇒ Fixnum
Page size.
Corresponds to the JSON property pageSize
1560 1561 1562 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 1560 def page_size @page_size end |
#page_token ⇒ String
Page token.
Corresponds to the JSON property pageToken
1565 1566 1567 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 1565 def page_token @page_token end |
#tool_names ⇒ Array<String>
List of tool names to for selective tool fetching.
Corresponds to the JSON property toolNames
1570 1571 1572 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 1570 def tool_names @tool_names end |
#tool_spec ⇒ Google::Apis::ConnectorsV2::ToolSpec
List of tool specifications.
Corresponds to the JSON property toolSpec
1575 1576 1577 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 1575 def tool_spec @tool_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1582 1583 1584 1585 1586 1587 1588 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 1582 def update!(**args) @execution_config = args[:execution_config] if args.key?(:execution_config) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @tool_names = args[:tool_names] if args.key?(:tool_names) @tool_spec = args[:tool_spec] if args.key?(:tool_spec) end |