Class: Google::Apis::ConnectorsV2::NodeSloMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV2::NodeSloMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v2/classes.rb,
lib/google/apis/connectors_v2/representations.rb,
lib/google/apis/connectors_v2/representations.rb
Overview
Node information for custom per-node SLO implementations. SSA does not support per-node SLO, but producers can populate per-node information in SloMetadata for custom precomputations. SSA Eligibility Exporter will emit per-node metric based on this information.
Instance Attribute Summary collapse
-
#location ⇒ String
The location of the node, if different from instance location.
-
#node_id ⇒ String
The id of the node.
-
#per_sli_eligibility ⇒ Google::Apis::ConnectorsV2::PerSliSloEligibility
PerSliSloEligibility is a mapping from an SLI name to eligibility.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeSloMetadata
constructor
A new instance of NodeSloMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeSloMetadata
Returns a new instance of NodeSloMetadata.
1824 1825 1826 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 1824 def initialize(**args) update!(**args) end |
Instance Attribute Details
#location ⇒ String
The location of the node, if different from instance location.
Corresponds to the JSON property location
1812 1813 1814 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 1812 def location @location end |
#node_id ⇒ String
The id of the node. This should be equal to SaasInstanceNode.node_id.
Corresponds to the JSON property nodeId
1817 1818 1819 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 1817 def node_id @node_id end |
#per_sli_eligibility ⇒ Google::Apis::ConnectorsV2::PerSliSloEligibility
PerSliSloEligibility is a mapping from an SLI name to eligibility.
Corresponds to the JSON property perSliEligibility
1822 1823 1824 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 1822 def per_sli_eligibility @per_sli_eligibility end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1829 1830 1831 1832 1833 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 1829 def update!(**args) @location = args[:location] if args.key?(:location) @node_id = args[:node_id] if args.key?(:node_id) @per_sli_eligibility = args[:per_sli_eligibility] if args.key?(:per_sli_eligibility) end |