Class: Google::Apis::ConnectorsV2::RefreshAccessTokenResponse
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV2::RefreshAccessTokenResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v2/classes.rb,
lib/google/apis/connectors_v2/representations.rb,
lib/google/apis/connectors_v2/representations.rb
Overview
RefreshAccessTokenResponse includes the returned access token and its associated credentials.
Instance Attribute Summary collapse
-
#access_credentials ⇒ Google::Apis::ConnectorsV2::AccessCredentials
AccessCredentials includes the OAuth access token, and the other fields returned along with it.
-
#metadata ⇒ Hash<String,Hash<String,Object>>
Metadata like service latency, etc.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RefreshAccessTokenResponse
constructor
A new instance of RefreshAccessTokenResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RefreshAccessTokenResponse
Returns a new instance of RefreshAccessTokenResponse.
2084 2085 2086 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 2084 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_credentials ⇒ Google::Apis::ConnectorsV2::AccessCredentials
AccessCredentials includes the OAuth access token, and the other fields
returned along with it.
Corresponds to the JSON property accessCredentials
2077 2078 2079 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 2077 def access_credentials @access_credentials end |
#metadata ⇒ Hash<String,Hash<String,Object>>
Metadata like service latency, etc.
Corresponds to the JSON property metadata
2082 2083 2084 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 2082 def @metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2089 2090 2091 2092 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 2089 def update!(**args) @access_credentials = args[:access_credentials] if args.key?(:access_credentials) @metadata = args[:metadata] if args.key?(:metadata) end |