Class: Google::Apis::ConnectorsV2::Resource
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV2::Resource
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v2/classes.rb,
lib/google/apis/connectors_v2/representations.rb,
lib/google/apis/connectors_v2/representations.rb
Instance Attribute Summary collapse
-
#_meta ⇒ Hash<String,Object>
Metadata for the resource.
-
#description ⇒ String
A description of what this resource represents.
-
#mime_type ⇒ String
The MIME type of this resource, if known.
-
#name ⇒ String
A human-readable name for this resource.
-
#size ⇒ Fixnum
The size of the raw resource content, in bytes, if known.
-
#uri ⇒ String
The URI of this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Resource
constructor
A new instance of Resource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Resource
Returns a new instance of Resource.
2129 2130 2131 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 2129 def initialize(**args) update!(**args) end |
Instance Attribute Details
#_meta ⇒ Hash<String,Object>
Metadata for the resource.
Corresponds to the JSON property _meta
2102 2103 2104 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 2102 def @_meta end |
#description ⇒ String
A description of what this resource represents.
Corresponds to the JSON property description
2107 2108 2109 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 2107 def description @description end |
#mime_type ⇒ String
The MIME type of this resource, if known.
Corresponds to the JSON property mimeType
2112 2113 2114 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 2112 def mime_type @mime_type end |
#name ⇒ String
A human-readable name for this resource.
Corresponds to the JSON property name
2117 2118 2119 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 2117 def name @name end |
#size ⇒ Fixnum
The size of the raw resource content, in bytes, if known.
Corresponds to the JSON property size
2122 2123 2124 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 2122 def size @size end |
#uri ⇒ String
The URI of this resource.
Corresponds to the JSON property uri
2127 2128 2129 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 2127 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2134 2135 2136 2137 2138 2139 2140 2141 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 2134 def update!(**args) @_meta = args[:_meta] if args.key?(:_meta) @description = args[:description] if args.key?(:description) @mime_type = args[:mime_type] if args.key?(:mime_type) @name = args[:name] if args.key?(:name) @size = args[:size] if args.key?(:size) @uri = args[:uri] if args.key?(:uri) end |