Class: Google::Apis::ConnectorsV2::ResultMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v2/classes.rb,
lib/google/apis/connectors_v2/representations.rb,
lib/google/apis/connectors_v2/representations.rb

Overview

Result Metadata message contains metadata about the result returned after executing an Action.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResultMetadata

Returns a new instance of ResultMetadata.



2181
2182
2183
# File 'lib/google/apis/connectors_v2/classes.rb', line 2181

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_typeString

The data type of the metadata field Corresponds to the JSON property dataType

Returns:

  • (String)


2152
2153
2154
# File 'lib/google/apis/connectors_v2/classes.rb', line 2152

def data_type
  @data_type
end

#default_valueObject

The following field specifies the default value of the Parameter provided by the external system if a value is not provided. Corresponds to the JSON property defaultValue

Returns:

  • (Object)


2158
2159
2160
# File 'lib/google/apis/connectors_v2/classes.rb', line 2158

def default_value
  @default_value
end

#descriptionString

A brief description of the metadata field. Corresponds to the JSON property description

Returns:

  • (String)


2163
2164
2165
# File 'lib/google/apis/connectors_v2/classes.rb', line 2163

def description
  @description
end

#json_schemaGoogle::Apis::ConnectorsV2::JsonSchema

JsonSchema representation of schema metadata Corresponds to the JSON property jsonSchema



2168
2169
2170
# File 'lib/google/apis/connectors_v2/classes.rb', line 2168

def json_schema
  @json_schema
end

#nameString

Name of the metadata field. Corresponds to the JSON property name

Returns:

  • (String)


2173
2174
2175
# File 'lib/google/apis/connectors_v2/classes.rb', line 2173

def name
  @name
end

#nullableBoolean Also known as: nullable?

Specifies whether a null value is allowed. Corresponds to the JSON property nullable

Returns:

  • (Boolean)


2178
2179
2180
# File 'lib/google/apis/connectors_v2/classes.rb', line 2178

def nullable
  @nullable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2186
2187
2188
2189
2190
2191
2192
2193
# File 'lib/google/apis/connectors_v2/classes.rb', line 2186

def update!(**args)
  @data_type = args[:data_type] if args.key?(:data_type)
  @default_value = args[:default_value] if args.key?(:default_value)
  @description = args[:description] if args.key?(:description)
  @json_schema = args[:json_schema] if args.key?(:json_schema)
  @name = args[:name] if args.key?(:name)
  @nullable = args[:nullable] if args.key?(:nullable)
end