Class: Google::Apis::ConnectorsV2::Schedule
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV2::Schedule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v2/classes.rb,
lib/google/apis/connectors_v2/representations.rb,
lib/google/apis/connectors_v2/representations.rb
Overview
Configure the schedule.
Instance Attribute Summary collapse
-
#day ⇒ String
Allows to define schedule that runs specified day of the week.
-
#duration ⇒ String
Output only.
-
#start_time ⇒ Google::Apis::ConnectorsV2::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Schedule
constructor
A new instance of Schedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Schedule
Returns a new instance of Schedule.
2217 2218 2219 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 2217 def initialize(**args) update!(**args) end |
Instance Attribute Details
#day ⇒ String
Allows to define schedule that runs specified day of the week.
Corresponds to the JSON property day
2203 2204 2205 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 2203 def day @day end |
#duration ⇒ String
Output only. Duration of the time window, set by service producer.
Corresponds to the JSON property duration
2208 2209 2210 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 2208 def duration @duration end |
#start_time ⇒ Google::Apis::ConnectorsV2::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property startTime
2215 2216 2217 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 2215 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2222 2223 2224 2225 2226 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 2222 def update!(**args) @day = args[:day] if args.key?(:day) @duration = args[:duration] if args.key?(:duration) @start_time = args[:start_time] if args.key?(:start_time) end |