Class: Google::Apis::ConnectorsV2::SloEligibility

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v2/classes.rb,
lib/google/apis/connectors_v2/representations.rb,
lib/google/apis/connectors_v2/representations.rb

Overview

SloEligibility is a tuple containing eligibility value: true if an instance is eligible for SLO calculation or false if it should be excluded from all SLO- related calculations along with a user-defined reason.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SloEligibility

Returns a new instance of SloEligibility.



2247
2248
2249
# File 'lib/google/apis/connectors_v2/classes.rb', line 2247

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#eligibleBoolean Also known as: eligible?

Whether an instance is eligible or ineligible. Corresponds to the JSON property eligible

Returns:

  • (Boolean)


2238
2239
2240
# File 'lib/google/apis/connectors_v2/classes.rb', line 2238

def eligible
  @eligible
end

#reasonString

User-defined reason for the current value of instance eligibility. Usually, this can be directly mapped to the internal state. An empty reason is allowed. Corresponds to the JSON property reason

Returns:

  • (String)


2245
2246
2247
# File 'lib/google/apis/connectors_v2/classes.rb', line 2245

def reason
  @reason
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2252
2253
2254
2255
# File 'lib/google/apis/connectors_v2/classes.rb', line 2252

def update!(**args)
  @eligible = args[:eligible] if args.key?(:eligible)
  @reason = args[:reason] if args.key?(:reason)
end