Class: Google::Apis::ConnectorsV2::SloMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v2/classes.rb,
lib/google/apis/connectors_v2/representations.rb,
lib/google/apis/connectors_v2/representations.rb

Overview

SloMetadata contains resources required for proper SLO classification of the instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SloMetadata

Returns a new instance of SloMetadata.



2283
2284
2285
# File 'lib/google/apis/connectors_v2/classes.rb', line 2283

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nodesArray<Google::Apis::ConnectorsV2::NodeSloMetadata>

Optional. List of nodes. Some producers need to use per-node metadata to calculate SLO. This field allows such producers to publish per-node SLO meta data, which will be consumed by SSA Eligibility Exporter and published in the form of per node metric to Monarch. Corresponds to the JSON property nodes



2269
2270
2271
# File 'lib/google/apis/connectors_v2/classes.rb', line 2269

def nodes
  @nodes
end

#per_sli_eligibilityGoogle::Apis::ConnectorsV2::PerSliSloEligibility

PerSliSloEligibility is a mapping from an SLI name to eligibility. Corresponds to the JSON property perSliEligibility



2274
2275
2276
# File 'lib/google/apis/connectors_v2/classes.rb', line 2274

def per_sli_eligibility
  @per_sli_eligibility
end

#tierString

Name of the SLO tier the Instance belongs to. This name will be expected to match the tiers specified in the service SLO configuration. Field is mandatory and must not be empty. Corresponds to the JSON property tier

Returns:

  • (String)


2281
2282
2283
# File 'lib/google/apis/connectors_v2/classes.rb', line 2281

def tier
  @tier
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2288
2289
2290
2291
2292
# File 'lib/google/apis/connectors_v2/classes.rb', line 2288

def update!(**args)
  @nodes = args[:nodes] if args.key?(:nodes)
  @per_sli_eligibility = args[:per_sli_eligibility] if args.key?(:per_sli_eligibility)
  @tier = args[:tier] if args.key?(:tier)
end