Class: Google::Apis::ConnectorsV2::Tool

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v2/classes.rb,
lib/google/apis/connectors_v2/representations.rb,
lib/google/apis/connectors_v2/representations.rb

Overview

Message representing a single tool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Tool

Returns a new instance of Tool.



2379
2380
2381
# File 'lib/google/apis/connectors_v2/classes.rb', line 2379

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#_metaHash<String,Object>

Metadata for the tool. Corresponds to the JSON property _meta

Returns:

  • (Hash<String,Object>)


2347
2348
2349
# File 'lib/google/apis/connectors_v2/classes.rb', line 2347

def _meta
  @_meta
end

#annotationsGoogle::Apis::ConnectorsV2::ToolAnnotations

ToolAnnotations holds annotations for a tool. Corresponds to the JSON property annotations



2352
2353
2354
# File 'lib/google/apis/connectors_v2/classes.rb', line 2352

def annotations
  @annotations
end

#depends_onArray<String>

List of tool names that this tool depends on. Corresponds to the JSON property dependsOn

Returns:

  • (Array<String>)


2357
2358
2359
# File 'lib/google/apis/connectors_v2/classes.rb', line 2357

def depends_on
  @depends_on
end

#descriptionString

Description of the tool. Corresponds to the JSON property description

Returns:

  • (String)


2362
2363
2364
# File 'lib/google/apis/connectors_v2/classes.rb', line 2362

def description
  @description
end

#input_schemaGoogle::Apis::ConnectorsV2::JsonSchema

JsonSchema representation of schema metadata Corresponds to the JSON property inputSchema



2367
2368
2369
# File 'lib/google/apis/connectors_v2/classes.rb', line 2367

def input_schema
  @input_schema
end

#nameString

Name of the tool. Corresponds to the JSON property name

Returns:

  • (String)


2372
2373
2374
# File 'lib/google/apis/connectors_v2/classes.rb', line 2372

def name
  @name
end

#output_schemaGoogle::Apis::ConnectorsV2::JsonSchema

JsonSchema representation of schema metadata Corresponds to the JSON property outputSchema



2377
2378
2379
# File 'lib/google/apis/connectors_v2/classes.rb', line 2377

def output_schema
  @output_schema
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2384
2385
2386
2387
2388
2389
2390
2391
2392
# File 'lib/google/apis/connectors_v2/classes.rb', line 2384

def update!(**args)
  @_meta = args[:_meta] if args.key?(:_meta)
  @annotations = args[:annotations] if args.key?(:annotations)
  @depends_on = args[:depends_on] if args.key?(:depends_on)
  @description = args[:description] if args.key?(:description)
  @input_schema = args[:input_schema] if args.key?(:input_schema)
  @name = args[:name] if args.key?(:name)
  @output_schema = args[:output_schema] if args.key?(:output_schema)
end