Class: Google::Apis::ConnectorsV2::ToolAnnotations

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/connectors_v2/classes.rb,
lib/google/apis/connectors_v2/representations.rb,
lib/google/apis/connectors_v2/representations.rb

Overview

ToolAnnotations holds annotations for a tool.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ToolAnnotations

Returns a new instance of ToolAnnotations.



2434
2435
2436
# File 'lib/google/apis/connectors_v2/classes.rb', line 2434

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#destructive_hintBoolean Also known as: destructive_hint?

If true, the tool may perform destructive updates to its environment. If false, the tool performs only additive updates. (This property is meaningful only when read_only_hint == false) Corresponds to the JSON property destructiveHint

Returns:

  • (Boolean)


2404
2405
2406
# File 'lib/google/apis/connectors_v2/classes.rb', line 2404

def destructive_hint
  @destructive_hint
end

#idempotent_hintBoolean Also known as: idempotent_hint?

If true, calling the tool repeatedly with the same arguments will have no additional effect on the environment. (This property is meaningful only when read_only_hint == false) Corresponds to the JSON property idempotentHint

Returns:

  • (Boolean)


2412
2413
2414
# File 'lib/google/apis/connectors_v2/classes.rb', line 2412

def idempotent_hint
  @idempotent_hint
end

#open_world_hintBoolean Also known as: open_world_hint?

If true, this tool may interact with an "open world" of external entities. If false, the tool's domain of interaction is closed. For example, the world of a web search tool is open, whereas that of a memory tool is not. Corresponds to the JSON property openWorldHint

Returns:

  • (Boolean)


2420
2421
2422
# File 'lib/google/apis/connectors_v2/classes.rb', line 2420

def open_world_hint
  @open_world_hint
end

#read_only_hintBoolean Also known as: read_only_hint?

If true, the tool does not modify its environment. Corresponds to the JSON property readOnlyHint

Returns:

  • (Boolean)


2426
2427
2428
# File 'lib/google/apis/connectors_v2/classes.rb', line 2426

def read_only_hint
  @read_only_hint
end

#titleString

A human-readable title for the tool. Corresponds to the JSON property title

Returns:

  • (String)


2432
2433
2434
# File 'lib/google/apis/connectors_v2/classes.rb', line 2432

def title
  @title
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2439
2440
2441
2442
2443
2444
2445
# File 'lib/google/apis/connectors_v2/classes.rb', line 2439

def update!(**args)
  @destructive_hint = args[:destructive_hint] if args.key?(:destructive_hint)
  @idempotent_hint = args[:idempotent_hint] if args.key?(:idempotent_hint)
  @open_world_hint = args[:open_world_hint] if args.key?(:open_world_hint)
  @read_only_hint = args[:read_only_hint] if args.key?(:read_only_hint)
  @title = args[:title] if args.key?(:title)
end