Class: Google::Apis::ConnectorsV2::ToolName
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV2::ToolName
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v2/classes.rb,
lib/google/apis/connectors_v2/representations.rb,
lib/google/apis/connectors_v2/representations.rb
Instance Attribute Summary collapse
-
#entity_name ⇒ String
Entity name for which the tool was generated.
-
#name ⇒ String
Tool name that was generated in the list tools call.
-
#operation ⇒ String
Operation for which the tool was generated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ToolName
constructor
A new instance of ToolName.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ToolName
Returns a new instance of ToolName.
2467 2468 2469 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 2467 def initialize(**args) update!(**args) end |
Instance Attribute Details
#entity_name ⇒ String
Entity name for which the tool was generated.
Corresponds to the JSON property entityName
2455 2456 2457 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 2455 def entity_name @entity_name end |
#name ⇒ String
Tool name that was generated in the list tools call.
Corresponds to the JSON property name
2460 2461 2462 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 2460 def name @name end |
#operation ⇒ String
Operation for which the tool was generated.
Corresponds to the JSON property operation
2465 2466 2467 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 2465 def operation @operation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2472 2473 2474 2475 2476 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 2472 def update!(**args) @entity_name = args[:entity_name] if args.key?(:entity_name) @name = args[:name] if args.key?(:name) @operation = args[:operation] if args.key?(:operation) end |