Class: Google::Apis::ConnectorsV2::ExchangeAuthCodeRequest
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV2::ExchangeAuthCodeRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v2/classes.rb,
lib/google/apis/connectors_v2/representations.rb,
lib/google/apis/connectors_v2/representations.rb
Overview
ExchangeAuthCodeRequest currently includes the auth code data.
Instance Attribute Summary collapse
-
#auth_code_data ⇒ Google::Apis::ConnectorsV2::AuthCodeData
AuthCodeData contains the data the runtime plane will give the connector backend in exchange for access and refresh tokens.
-
#execution_config ⇒ Google::Apis::ConnectorsV2::ExecutionConfig
ExecutionConfig contains the configuration for the execution of the request.
-
#oauth2_config ⇒ Google::Apis::ConnectorsV2::OAuth2Config
OAuth2Config contains the OAuth2 config for the connection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExchangeAuthCodeRequest
constructor
A new instance of ExchangeAuthCodeRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExchangeAuthCodeRequest
Returns a new instance of ExchangeAuthCodeRequest.
444 445 446 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 444 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auth_code_data ⇒ Google::Apis::ConnectorsV2::AuthCodeData
AuthCodeData contains the data the runtime plane will give the connector
backend in exchange for access and refresh tokens.
Corresponds to the JSON property authCodeData
432 433 434 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 432 def auth_code_data @auth_code_data end |
#execution_config ⇒ Google::Apis::ConnectorsV2::ExecutionConfig
ExecutionConfig contains the configuration for the execution of the request.
Corresponds to the JSON property executionConfig
437 438 439 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 437 def execution_config @execution_config end |
#oauth2_config ⇒ Google::Apis::ConnectorsV2::OAuth2Config
OAuth2Config contains the OAuth2 config for the connection.
Corresponds to the JSON property oauth2Config
442 443 444 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 442 def oauth2_config @oauth2_config end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
449 450 451 452 453 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 449 def update!(**args) @auth_code_data = args[:auth_code_data] if args.key?(:auth_code_data) @execution_config = args[:execution_config] if args.key?(:execution_config) @oauth2_config = args[:oauth2_config] if args.key?(:oauth2_config) end |