Class: Google::Apis::ConnectorsV2::ExecuteActionResponse
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV2::ExecuteActionResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v2/classes.rb,
lib/google/apis/connectors_v2/representations.rb,
lib/google/apis/connectors_v2/representations.rb
Overview
Response message for ActionService.ExecuteAction
Instance Attribute Summary collapse
-
#metadata ⇒ Hash<String,Hash<String,Object>>
Metadata like service latency, etc.
-
#results ⇒ Array<Hash<String,Object>>
In the case of successful invocation of the specified action, the results Struct contains values based on the response of the action invoked.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExecuteActionResponse
constructor
A new instance of ExecuteActionResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExecuteActionResponse
Returns a new instance of ExecuteActionResponse.
527 528 529 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 527 def initialize(**args) update!(**args) end |
Instance Attribute Details
#metadata ⇒ Hash<String,Hash<String,Object>>
Metadata like service latency, etc.
Corresponds to the JSON property metadata
516 517 518 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 516 def @metadata end |
#results ⇒ Array<Hash<String,Object>>
In the case of successful invocation of the specified action, the results
Struct contains values based on the response of the action invoked. 1. If the
action execution produces any entities as a result, they are returned as an
array of Structs with the 'key' being the field name and the 'value' being the
value of that field in each result row. 'results': ['key': 'value', ...]
Corresponds to the JSON property results
525 526 527 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 525 def results @results end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
532 533 534 535 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 532 def update!(**args) @metadata = args[:metadata] if args.key?(:metadata) @results = args[:results] if args.key?(:results) end |