Class: Google::Apis::ConnectorsV2::MaintenanceSchedule
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV2::MaintenanceSchedule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v2/classes.rb,
lib/google/apis/connectors_v2/representations.rb,
lib/google/apis/connectors_v2/representations.rb
Overview
Maintenance schedule which is exposed to customer and potentially end user, indicating published upcoming future maintenance schedule
Instance Attribute Summary collapse
-
#can_reschedule ⇒ Boolean
(also: #can_reschedule?)
This field is deprecated, and will be always set to true since reschedule can happen multiple times now.
-
#end_time ⇒ String
The scheduled end time for the maintenance.
-
#rollout_management_policy ⇒ String
The rollout management policy this maintenance schedule is associated with.
-
#schedule_deadline_time ⇒ String
schedule_deadline_time is the time deadline any schedule start time cannot go beyond, including reschedule.
-
#start_time ⇒ String
The scheduled start time for the maintenance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MaintenanceSchedule
constructor
A new instance of MaintenanceSchedule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MaintenanceSchedule
Returns a new instance of MaintenanceSchedule.
1722 1723 1724 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 1722 def initialize(**args) update!(**args) end |
Instance Attribute Details
#can_reschedule ⇒ Boolean Also known as: can_reschedule?
This field is deprecated, and will be always set to true since reschedule can
happen multiple times now. This field should not be removed until all service
producers remove this for their customers.
Corresponds to the JSON property canReschedule
1694 1695 1696 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 1694 def can_reschedule @can_reschedule end |
#end_time ⇒ String
The scheduled end time for the maintenance.
Corresponds to the JSON property endTime
1700 1701 1702 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 1700 def end_time @end_time end |
#rollout_management_policy ⇒ String
The rollout management policy this maintenance schedule is associated with.
When doing reschedule update request, the reschedule should be against this
given policy.
Corresponds to the JSON property rolloutManagementPolicy
1707 1708 1709 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 1707 def rollout_management_policy @rollout_management_policy end |
#schedule_deadline_time ⇒ String
schedule_deadline_time is the time deadline any schedule start time cannot go
beyond, including reschedule. It's normally the initial schedule start time
plus maintenance window length (1 day or 1 week). Maintenance cannot be
scheduled to start beyond this deadline.
Corresponds to the JSON property scheduleDeadlineTime
1715 1716 1717 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 1715 def schedule_deadline_time @schedule_deadline_time end |
#start_time ⇒ String
The scheduled start time for the maintenance.
Corresponds to the JSON property startTime
1720 1721 1722 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 1720 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1727 1728 1729 1730 1731 1732 1733 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 1727 def update!(**args) @can_reschedule = args[:can_reschedule] if args.key?(:can_reschedule) @end_time = args[:end_time] if args.key?(:end_time) @rollout_management_policy = args[:rollout_management_policy] if args.key?(:rollout_management_policy) @schedule_deadline_time = args[:schedule_deadline_time] if args.key?(:schedule_deadline_time) @start_time = args[:start_time] if args.key?(:start_time) end |