Class: Google::Apis::ConnectorsV2::RefreshAccessTokenRequest
- Inherits:
-
Object
- Object
- Google::Apis::ConnectorsV2::RefreshAccessTokenRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/connectors_v2/classes.rb,
lib/google/apis/connectors_v2/representations.rb,
lib/google/apis/connectors_v2/representations.rb
Overview
RefreshAccessTokenRequest includes the refresh token.
Instance Attribute Summary collapse
-
#execution_config ⇒ Google::Apis::ConnectorsV2::ExecutionConfig
ExecutionConfig contains the configuration for the execution of the request.
-
#oauth2_config ⇒ Google::Apis::ConnectorsV2::OAuth2Config
OAuth2Config contains the OAuth2 config for the connection.
-
#refresh_token ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RefreshAccessTokenRequest
constructor
A new instance of RefreshAccessTokenRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RefreshAccessTokenRequest
Returns a new instance of RefreshAccessTokenRequest.
2056 2057 2058 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 2056 def initialize(**args) update!(**args) end |
Instance Attribute Details
#execution_config ⇒ Google::Apis::ConnectorsV2::ExecutionConfig
ExecutionConfig contains the configuration for the execution of the request.
Corresponds to the JSON property executionConfig
2043 2044 2045 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 2043 def execution_config @execution_config end |
#oauth2_config ⇒ Google::Apis::ConnectorsV2::OAuth2Config
OAuth2Config contains the OAuth2 config for the connection.
Corresponds to the JSON property oauth2Config
2048 2049 2050 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 2048 def oauth2_config @oauth2_config end |
#refresh_token ⇒ String
Optional. Refresh Token String. If the Refresh Token is not provided, the
runtime will read the data from the secret manager.
Corresponds to the JSON property refreshToken
2054 2055 2056 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 2054 def refresh_token @refresh_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2061 2062 2063 2064 2065 |
# File 'lib/google/apis/connectors_v2/classes.rb', line 2061 def update!(**args) @execution_config = args[:execution_config] if args.key?(:execution_config) @oauth2_config = args[:oauth2_config] if args.key?(:oauth2_config) @refresh_token = args[:refresh_token] if args.key?(:refresh_token) end |